/*
    This file is part of Kiten, a KDE Japanese Reference Tool
    SPDX-FileCopyrightText: 2011 Daniel E. Moctezuma <democtezuma@gmail.com>

    SPDX-License-Identifier: LGPL-2.0-or-later
*/

#ifndef KITEN_MACROS_H
#define KITEN_MACROS_H

#define EDICT QStringLiteral("edict")
#define KANJIDIC QStringLiteral("kanjidic")

#endif
